# Access Policy

The Access policy module combines Drupal's role based access control (RBAC) architecture
with an Attribute Based Access Control (ABAC) architecture to create an incredibly
powerful and flexible system for managing access to your content.

To achieve this, Access Policy leverages Drupal fields as the attributes. For example,
to restrict content by department all you need to do is add a "Department" taxonomy
term entity reference field to a content type and user and then set up your access
policy to use it. No code necessary.

With Access Policy you can do things like:

- Restrict content to members in a particular group or department
- Restrict content by region
- Restrict content by priority or security level such as Secret, confidential,
  public etc.
- Make content private while granting some access to specific users. Very useful when
  complimented with content moderation.
- Create public content which can be viewed by anyone but moderated by a core team.
- Disable/enable policies on node-by-node basis.
- Show a custom 403 message.

Any many, many more use cases.

- For a full description of the module, visit the [project page].
- To submit bug reports and feature suggestions, or to track changes, use the
  [issue queue].

[Project page]: https://www.drupal.org/project/access_policy
[issue queue]: https://www.drupal.org/project/issues/access_policy


## Table of contents

- Requirements
- Installation
- Configuration
- Information for developers

## Requirements

No other modules are required.

## Installation

- Install as you would normally install a contributed Drupal module. For further
  information, see _[Installing Drupal Modules]_.

[Installing Drupal Modules]: https://www.drupal.org/docs/extending-drupal/installing-drupal-modules

## Configuration

After installation, you can start creating access policies immediately. To create
your first policy go to `/admin/people/access-policies`and add a policy. From there
you can enable the policy for different bundles, set a custom 403 message, and
add access rules. Once your access policy is created go to
`/admin/people/permissions/module/access_policy` and configure the permissions.
Finally, find the entity that you want to restrict access, go to the "Access"
tab and choose the Access policy from the select list.

[Getting started]: https://www.drupal.org/docs/8/modules/access-policy/getting-started

## Information for developers

### Hooks

Access policy comes with two hooks.

| Hook                          | Description                                      |
|-------------------------------|--------------------------------------------------|
| hook_access_policy_data       | Defines access policy handler data definition.   |
| hook_access_policy_data_alter | Alter the access policy handler data definition. |

For more details please see access_policy.api.php.

### Plugins

Access policy is highly extensible with custom plugins for Access policy types,
Access rules, Access rule widgets, Access rule arguments, Selection rules and 403 responses.
This gives developers complete control of how to define their access scheme.

| Plugin type           | Directory                | Description                                                             |
|-----------------------|--------------------------|-------------------------------------------------------------------------|
| Access policy type    | `src/AccessPolicyType`   | Defines the operation validation strategy (permissions, rules or both). |
| Access policy query   | `src/AccessPolicyQuery`  | Database query integration.                                             |
| Access rule           | `src/AccessRule`         | Define custom validation rules based on attributes.                     |
| Access rule argument  | `src/AccessRuleArgument` | Provides contextual arguments for access rules.                         |
| Access rule widget    | `src/AccessRuleWidget`   | Displays a widget from the Access policy selection tab.                 |
| Selection rule        | `src/AccessRule`         | Define custom policy selection rules based on attributes.               |
| 403 response behavior | `src/Http403Response`    | Render a custom 403 message.                                            |

