<?php

/**
 * @file
 * Post update functions for access policy.
 */

/**
 * Add support for multiple access policies on entities.
 */
function access_policy_post_update_update_storage(&$sandbox) {
  $connection = \Drupal::database();
  $entityTypeManager = \Drupal::service('entity_type.manager');
  $storage = \Drupal::service('access_policy.storage.entity');
  $oldStorage = \Drupal::service('access_policy.storage.content');

  $entity_types = $entityTypeManager->getDefinitions();
  foreach ($entity_types as $entity_type) {
    if (\Drupal::service('access_policy.information')->isSupportedEntityType($entity_type)) {
      // Make sure that the table is setup.
      $storage->installSchema($entity_type);

      // Only copy the content over if the original storage is not empty and the
      // new storage is empty.
      if (!$oldStorage->isEmpty($entity_type) && $storage->isEmpty($entity_type->id())) {
        $base_table = $entity_type->getBaseTable();
        $bundle_key = $entity_type->getKey('bundle');
        $id_key = $entity_type->getKey('id');

        // Do a bulk insert of values into the new table.
        $query = $connection->select('content_access_policy', 'cap');

        $query->addExpression("[et].[{$bundle_key}]", 'bundle');
        $query->addExpression('[cap].[content_entity_id]', 'entity_id');
        $query->addExpression('[cap].[access_policy]', 'access_policy');

        $query->condition('cap.content_entity_type_id', $entity_type->id());
        $query->condition('cap.access_policy', NULL, 'IS NOT NULL');
        $query->join($base_table, 'et', "et.{$id_key} = cap.content_entity_id");

        $connection->insert($storage->getTable($entity_type->id()))
          ->from($query)
          ->execute();
      }
    }
  }

}
