<?php

namespace Drupal\access_policy;

/**
 * Trait for toggling between storages.
 *
 * This is to ease the transition over from the old, content access policy
 * entity storage to the new custom storage.
 */
trait EntityAccessPolicyStorageTrait {

  /**
   * Get the entity access policy storage service.
   *
   * @return \Drupal\access_policy\EntityAccessPolicyStorageInterface
   *   The storage service
   */
  public function getEntityPolicyStorage() {
    return \Drupal::service('access_policy.storage.' . $this->getActiveStorageEngine());
  }

  /**
   * The current active storage engine.
   *
   * Accepted values are 'entity' (new), and 'content' (old).
   *
   * @return string
   *   The storage engine.
   */
  private function getActiveStorageEngine() {
    $settings = \Drupal::config('access_policy.settings');
    if ($settings->get('storage_engine')) {
      return $settings->get('storage_engine');
    }

    return 'entity';
  }

}
