<?php

namespace Drupal\access_policy\Plugin\AccessPolicyType;

use Drupal\Core\Plugin\PluginBase;

/**
 * Class Access policy type base.
 */
abstract class AccessPolicyTypeBase extends PluginBase implements AccessPolicyTypeInterface {

  /**
   * {@inheritdoc}
   */
  public function shouldValidatePermission($op) {
    if (!empty($this->pluginDefinition['operations'][$op]['permission'])) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function shouldValidateRules($op) {
    if (isset($this->pluginDefinition['operations'][$op]['rules'])) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function ruleValidationEnabled($op) {
    if (!empty($this->pluginDefinition['operations'][$op]['rules'])) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getAllOperations() {
    return array_keys($this->pluginDefinition['operations']);
  }

  /**
   * {@inheritdoc}
   */
  public function getRuleOperations() {
    $operations = [];
    foreach ($this->pluginDefinition['operations'] as $op => $restriction) {
      if (isset($restriction['rules'])) {
        $operations[$op] = $restriction['rules'];
      }
    }
    return $operations;
  }

  /**
   * {@inheritdoc}
   */
  public function getPermissionOperations() {
    $operations = [];
    foreach ($this->pluginDefinition['operations'] as $op => $restriction) {
      if (isset($restriction['permission'])) {
        $operations[] = $op;
      }
    }
    return $operations;
  }

  /**
   * {@inheritdoc}
   */
  public function supportsPermissions() {
    foreach ($this->pluginDefinition['operations'] as $restriction) {
      if (!empty($restriction['permission'])) {
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function supportsRules() {
    foreach ($this->pluginDefinition['operations'] as $restriction) {
      if (isset($restriction['rules'])) {
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getTypeRules() {
    if (!empty($this->pluginDefinition['access_rules'])) {
      return $this->pluginDefinition['access_rules'];
    }
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function hasTypeRules() {
    if (!empty($this->pluginDefinition['access_rules'])) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getTypeSelectionRules() {
    if (!empty($this->pluginDefinition['selection_rules'])) {
      return $this->pluginDefinition['selection_rules'];
    }
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function hasTypeSelectionRules() {
    if (!empty($this->pluginDefinition['selection_rules'])) {
      return TRUE;
    }
    return FALSE;
  }

}
