<?php

namespace Drupal\access_policy\Plugin\AccessRule;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Is authored by the current user.
 *
 * Checks to see if the entity was created by the current user.
 *
 * @AccessRule(
 *   id = "is_own",
 *   handlers = {
 *     "query_alter" = "\Drupal\access_policy\AccessRuleQueryHandler\IsOwn"
 *   }
 * )
 */
class IsOwn extends AccessRuleBase {

  /**
   * {@inheritdoc}
   */
  public function isApplicable(EntityInterface $entity) {
    if ($entity instanceof EntityOwnerInterface) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function validate(EntityInterface $entity, AccountInterface $account) {
    if ($entity->getOwnerId() == $account->id()) {
      return TRUE;
    }

    return FALSE;
  }

}
