<?php

namespace Drupal\access_policy\Plugin\SelectionRule;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Is authored by the current user.
 *
 * Checks to see if the entity was created by the current user.
 *
 * @SelectionRule(
 *   id = "is_own",
 * )
 */
class IsOwn extends SelectionRuleBase {

  /**
   * {@inheritdoc}
   */
  public function isApplicable(EntityInterface $entity) {
    // If the user is the original owner then allow the policy to be selected.
    if ($entity instanceof EntityOwnerInterface) {
      $user = \Drupal::currentUser();
      return $this->isOriginalOwner($entity, $user);
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function validate(EntityInterface $entity, AccountInterface $account) {
    return $this->isOriginalOwner($entity, $account);
  }

  /**
   * Determine whether the user is the original owner.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current user.
   *
   * @return bool
   *   TRUE if the user is the original owner; FALSE otherwise.
   */
  protected function isOriginalOwner(EntityInterface $entity, AccountInterface $account) {
    if ($entity->getOwnerId() == $account->id()) {
      return TRUE;
    }

    return FALSE;
  }

}
