<?php

namespace Drupal\access_policy_test\Plugin\AccessRule;

use Drupal\Core\Database\Query\SelectInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\access_policy\Plugin\AccessRule\AccessRuleBase;
use Drupal\access_policy\Plugin\AccessRule\AccessRulePluginInterface;

/**
 * Matching text rule test.
 *
 * This is a very basic rule for testing purposes. It checks to see if a node
 * and users have the same value in a field_text text field.
 *
 * @AccessRule(
 *   id = "matching_text",
 * )
 */
class MatchingTextRuleTest extends AccessRuleBase implements AccessRulePluginInterface {

  /**
   * {@inheritdoc}
   */
  public function isApplicable(EntityInterface $entity) {
    if ($entity->hasField('field_text')) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function validate(EntityInterface $entity, AccountInterface $account) {
    if ($entity->get('field_text')->value == $account->get('field_text')->value) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function queryAlter(SelectInterface $query, AccountInterface $user) {
    $text = $user->get('field_text')->value;
    $base_field_placeholder = $query->getMetaData('base_table') . '.' . $query->getMetaData('base_field');
    $field_table = 'node__field_text';
    $query->leftJoin($field_table, $field_table, $field_table . ".entity_id = " . $base_field_placeholder);
    $query->condition($field_table . '.field_text_value', $text);
  }

}
