<?php

namespace Drupal\Tests\access_policy\Kernel\Plugin\AccessRule;

use Drupal\access_policy\Entity\AccessPolicy;
use Drupal\access_policy\Plugin\OperatorValidationTrait;
use Drupal\Tests\access_policy\Kernel\AccessPolicyKernelTestBase;

/**
 * Tests EntityFieldList plugin features.
 *
 * @group access_policy
 */
class EntityFieldTypeTest extends AccessPolicyKernelTestBase {

  use OperatorValidationTrait;

  /**
   * The modules to install.
   *
   * @var string[]
   */
  protected static $modules = [
    'field',
    'filter',
    'node',
    'options',
    'access_policy',
    'access_policy_test',
    'system',
    'text',
    'user',
    'datetime',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installConfig(['access_policy_test']);
  }

  /**
   * Tests list string with multiple access rules.
   */
  public function testEntityFieldType() {

    $policy = AccessPolicy::create([
      'id' => 'policy_bundle',
      'label' => 'Basic test policy',
      'target_entity_type_id' => 'node',
    ]);
    $policy->save();

    $access_rule = $this->accessRuleManager->getHandler('node', 'type');
    $access_rule->setSettings([
      'value' => [
        'page' => 'page',
      ],
      'operator' => 'or',
      'query' => TRUE,
    ]);
    $policy->addAccessRule($access_rule);
    $policy->save();

    // Create a basic node.
    $node_1 = $this->createNode([
      'title' => 'Node 1',
      'type' => 'page',
      'status' => 1,
    ]);

    $this->assignAccessPolicy($node_1, 'policy_bundle');

    $user = $this->createUser([
      'access content',
      'view policy_bundle content',
    ]);
    $user->save();

    $access = $this->accessPolicyValidator->validate($node_1, $user, 'view');
    $this->assertTrue($access, 'The user should have access');

    $this->setCurrentUser($user);
    $this->assertQueryResults('node', [
      $node_1->id(),
    ]);

    // Change the access rule settings and run validation again.
    $access_rule_settings = $access_rule->getSettings();
    $access_rule_settings['operator'] = 'not';
    $policy->updateAccessRule('type', $access_rule_settings);
    $policy->save();

    $access = $this->accessPolicyValidator->validate($node_1, $user, 'view');

    $this->assertFalse($access, 'The user should not have access');
    $this->assertQueryResults('node', []);
  }

}
